<?php
/**
 * JV Hosting functions and definitions
 *
 * Sets up the theme and provides some helper functions, which are used
 * in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook.
 *
 * For more information on hooks, actions, and filters, @link http://codex.wordpress.org/Plugin_API
 *
 * @package Hosting
 * @subpackage JV_Hosting
 * @since JV Hosting 1.0
 */
if( !function_exists( 'jv_hosting_footer_scripts' ) )
{
	function jv_hosting_footer_scripts()
	{
		wp_dequeue_script( 'wpb_composer_front_js' );
		wp_enqueue_script( 'wpb_composer_front_js_custom', get_template_directory_uri() . '/js/js_composer_front.js', array( 'jquery' ), '20141212', true );
	}
}
	add_action( 'jv_hosting_footer_scripts', 'jv_hosting_footer_scripts', 100000 );
if( !function_exists( 'jv_hosting_scripts' ) )
{
	function jv_hosting_scripts() {
		wp_enqueue_script( 'jv_hosting-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '20141212', true );
		
	}
	add_action( 'wp_enqueue_scripts', 'jv_hosting_scripts' );
}
require_once( get_template_directory() . '/library/jvLibrary.php');
require_once(get_template_directory() . '/library/jvthemes.php'); // framework functions file
//
// Set up the content width value based on the theme's design and stylesheet.
$themecolors = array(
    'bg' => 'eeeeee',
    'border' => 'eeeeee',
    'text' => '111111',
    'link' => '000000',
    'url' => '000000'
);
if ( ! isset( $content_width ) )
	$content_width = 625;


/**
 * JV Hosting setup.
 *
 * Sets up theme defaults and registers the various WordPress features that
 * JV Hosting supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add a Visual Editor stylesheet.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,
 * 	custom background, and post formats.
 * @uses register_nav_menu() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since JV Hosting 1.0
 */
 if( !function_exists( 'jv_hosting_setup' ) )
 {
	function jv_hosting_setup() {
		/*
		 * Makes JV Hosting available for translation.
		 *
		 * Translations can be added to the /languages/ directory.
		 * If you're building a theme based on JV Hosting, use a find and replace
		 * to change 'hosting' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'jv-hosting', get_template_directory() . '/languages' );

		// This theme styles the visual editor with editor-style.css to match the theme style.
		add_editor_style();

		// Adds RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );
		
		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// This theme supports a variety of post formats.
		add_theme_support( 'post-formats', array( 'aside', 'image', 'link', 'quote', 'status' ) );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'primary', __( 'Primary Menu', 'jv-hosting' ) );

		/*
		 * This theme supports custom background color and image,
		 * and here we also set up the default background color.
		 */
		add_theme_support( 'custom-background', array(
			'default-color' => 'e6e6e6',
		) );

		// This theme uses a custom image size for featured images, displayed on "standard" posts.
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 624, 9999 ); // Unlimited height, soft crop
		add_theme_support( 'jetpack-responsive-videos' );
	}
	add_action( 'after_setup_theme', 'jv_hosting_setup' );
}
// body class with setting theme
add_filter( 'body_class', 'JVLibrary::getClass', 10, 1 );



// download sample data
JVLibrary::downloadDataSanple();


/**
 * Add support for a custom header image.
 */
require( get_template_directory() . '/inc/custom-header.php' );

/**
 * Return the Google font stylesheet URL if available.
 *
 * The use of Open Sans by default is localized. For languages that use
 * characters not supported by the font, the font can be disabled.
 *
 * @since JV Hosting 1.2
 *
 * @return string Font stylesheet or empty string if disabled.
 */
if( !function_exists( 'jv_hosting_get_font_url' ) )
{
	function jv_hosting_get_font_url() {
		$font_url = '';

		return $font_url;	
	}
}

/**
 * Enqueue scripts and styles for front-end.
 *
 * @since JV Hosting 1.0
 */
 if( !function_exists( 'jv_hosting_scripts_styles' ) )
 {
	function jv_hosting_scripts_styles() {
		global $wp_styles;

		/*
		 * Adds JavaScript to pages with the comment form to support
		 * sites with threaded comments (when in use).
		 */
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
			wp_enqueue_script( 'comment-reply' );

		// Loads our main stylesheet.
		wp_enqueue_style( 'hosting-style', get_stylesheet_uri() );

		// Loads the Internet Explorer specific stylesheet.
		wp_enqueue_style( 'hosting-ie', get_template_directory_uri() . '/css/ie.css', array( 'hosting-style' ), '20121010' );
		$wp_styles->add_data( 'hosting-ie', 'conditional', 'lt IE 9' );
	}
	add_action( 'wp_enqueue_scripts', 'jv_hosting_scripts_styles' );
}
/**
 * Filter TinyMCE CSS path to include Google Fonts.
 *
 * Adds additional stylesheets to the TinyMCE editor if needed.
 *
 * @uses hosting_get_font_url() To get the Google Font stylesheet URL.
 *
 * @since JV Hosting 1.2
 *
 * @param string $mce_css CSS path to load in TinyMCE.
 * @return string Filtered CSS path.
 */
 if( !function_exists( 'jv_hosting_mce_css' ) )
 {
	function jv_hosting_mce_css( $mce_css ) {
		$font_url = jv_hosting_get_font_url();

		if ( empty( $font_url ) )
			return $mce_css;

		if ( ! empty( $mce_css ) )
			$mce_css .= ',';

		$mce_css .= esc_url_raw( str_replace( ',', '%2C', $font_url ) );

		return $mce_css;
	}
	add_filter( 'mce_css', 'jv_hosting_mce_css' );
}


/**
 * Filter the page menu arguments.
 *
 * Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
 *
 * @since JV Hosting 1.0
 */
 if( !function_exists( 'jv_hosting_page_menu_args' ) )
 {
	function jv_hosting_page_menu_args( $args ) {
		if ( ! isset( $args['show_home'] ) )
			$args['show_home'] = true;
		return $args;
	}
	add_filter( 'wp_page_menu_args', 'jv_hosting_page_menu_args' );
}
/**
 * Register sidebars.
 *
 * Registers our main widget area and the front page widget areas.
 *
 * @since JV Hosting 1.0
 */
 if( !function_exists( 'jv_hosting_widgets_init' ) )
 {
	function jv_hosting_widgets_init() {

		register_sidebar( array(
			'name' => __( 'Blog Sidebar', 'jv-hosting' ),
			'description'   => __( 'Add widgets here to appear in your Blog sidebar.', 'jv-hosting' ),
			'id' => 'sidebar-1',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );



		register_sidebar( array(
			'name' => __( 'Header', 'jv-hosting' ),
			'id' => 'sidebar-header',
			'description'   => __( 'Add widgets here to appear in your Header panel.', 'jv-hosting' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title ">',
			'after_title' => '</h3>',
		) );
		

		register_sidebar( array(
			'name' => __( 'Shop Sidebar', 'jv-hosting' ),
			'id' => 'shop-sidebar',
			'description'   => __( 'Add widgets here to appear in your Shop sidebar', 'jv-hosting' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title ">',
			'after_title' => '</h3>',
		) );
		

		register_sidebar( array(
			'name' => __( 'Buddypress sidebar', 'jv-hosting' ),
			'id' => 'buddypress-sidebar',
			'description'   => __( 'Add widgets here to appear in your Buddypress sidebar', 'jv-hosting' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title ">',
			'after_title' => '</h3>',
		) );		
		
		
		
		register_sidebar( array(
			'name' => __( 'Bottom Cloumm', 'jv-hosting' ),
			'id' => 'bottom',
			'description'   => __( 'Add widgets here to appear in your Bottom section - above Footer', 'jv-hosting' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );
		
		register_sidebar( array(
			'name' => __( 'Copyright', 'jv-hosting' ),
			'id' => 'footer',
			'description'   => __( 'Add widgets here to appear in your Copyright section', 'jv-hosting' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );


		
	}
	add_action( 'widgets_init', 'jv_hosting_widgets_init' );
}

if ( ! function_exists( 'jv_hosting_content_nav' ) ) :
/**
 * Displays navigation to next/previous pages when applicable.
 *
 * @since JV Hosting 1.0
 */
function jv_hosting_content_nav( $html_id ) {
	global $wp_query;

	$html_id = esc_attr( $html_id );

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo esc_attr($html_id); ?>" class="navigation" role="navigation">
			<h3 class="assistive-text"><?php _e( 'Post navigation', 'jv-hosting' ); ?></h3>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'jv-hosting' ) ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'jv-hosting' ) ); ?></div>
		</nav><!-- #<?php echo esc_attr($html_id); ?> .navigation -->
	<?php endif;
}
endif;

if ( ! function_exists( 'jv_hosting_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own hosting_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since JV Hosting 1.0
 */
function jv_hosting_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'jv-hosting' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'jv-hosting' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
		
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
        	<?php echo get_avatar( $comment, 60 ); ?>
        
			<div class="comment-right speech-bubble-comment classic">
				<div class="comment-inner">
					<header class="comment-meta comment-author vcard ItemLinks ItemLinksInline ItemLinksTop">
						<?php
							printf( '<span><i class="icon-calendar3"></i> <a href="%1$s"><time datetime="%2$s">%3$s</time></a></span>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'jv-hosting' ), get_comment_date(), get_comment_time() )
							);
								printf( '<span>%1$s<span class="text-primary"> %2$s</span> %3$s</span>',
								esc_attr_e( "Post by :", "jv-hosting"),
								get_comment_author_link(),
								
								// If current post author is also comment author, make it known visually.
								( $comment->user_id === $post->post_author ) ? '<span></span>' : ''
							);
						?>
						
						<?php edit_comment_link( __( 'Edit', 'jv-hosting' ), '<span class="edit-link pull-right"> <i class="icon-edit5"></i> ', '</span>' ); ?>
						
					</header><!-- .comment-meta -->

					<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'jv-hosting' ); ?></p>
					<?php endif; ?>

					<section class="comment-content comment">
						<?php comment_text(); ?>
					</section><!-- .comment-content -->
					
					<span class="comment-reply text-primary">
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'jv-hosting' ), 'after' => '<i class="icon-angle-right"></i>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
					</span>
					
				</div> <!--comment-inner-->
			</div><!--comment-right-->

		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'jv_hosting_entry_meta_full' ) ) :
/**
 * Set up post entry meta.
 *
 * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
 *
 * Create your own hosting_entry_meta_full() to override in a child theme.
 *
 * @since JV Hosting 1.0
 */
 
function jv_hosting_entry_meta_full() {
	// Translators: used between list items, there is a space after the comma.
	$categories_list = get_the_category_list( __( ', ', 'jv-hosting' ) );

	// Translators: used between list items, there is a space after the comma.
	$tag_list = get_the_tag_list( '', __( ', ', 'jv-hosting' ) );
	
	global $post;
	$dates=date('Y/m/d',strtotime($post->post_date));
	$dates_arr= explode("/",$dates);
	
	$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date " datetime="%3$s">%4$s</time></a>',
		esc_url(get_day_link($dates_arr[0],$dates_arr[1],$dates_arr[2])),
		esc_attr( get_the_time() ),
		esc_attr( date('Y/m/d H:i:s',strtotime($post->post_date)) ),
		esc_html( call_user_func( 'get_the_date' ) )
	);
	
	$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'jv-hosting' ), get_the_author() ) ),
		get_the_author()
	);

	// Translators: 1 is category, 2 is tag, 3 is the date and 4 is the author's name.
	if ( $tag_list ) {
		$utility_text = __( '
		<span class="category"> <i class="icon-folder2"></i>   %1$s</span> 
		<span class="tag"> <i class="icon-tags2"></i>   %2$s</span> 
		<span class="date"> <i class="icon-calendar3"></i>   %3$s</span> 
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		
		', 'jv-hosting' );
	} elseif ( $categories_list ) {
		$utility_text = __( '
		<span class="category"> <i class="icon-folder2"></i>   %1$s</span> 
		<span class="date"> <i class="icon-calendar3"></i>   %3$s</span> 
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		', 'jv-hosting' );
	} else {
		$utility_text = __( '
		<span class="date"> <i class="icon-calendar3"></i>   %3$s</span> 
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		
		
		', 'jv-hosting' );
	}

	printf(
		$utility_text,
		$categories_list,
		$tag_list,
		$date,
		$author
	);
}
endif;

if ( ! function_exists( 'jv_hosting_entry_meta' ) ) :
/**
 * Set up post entry meta.
 *
 * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
 *
 * Create your own hosting_entry_meta() to override in a child theme.
 *
 * @since JV Hosting 1.0
 */
 
function jv_hosting_entry_meta() {
	// Translators: used between list items, there is a space after the comma.
	$categories_list = get_the_category_list( __( ', ', 'jv-hosting' ) );

	// Translators: used between list items, there is a space after the comma.
	$tag_list = get_the_tag_list( '', __( ', ', 'jv-hosting' ) );
	
	global $post;
	$dates=date('Y/m/d',strtotime($post->post_date));
	$dates_arr= explode("/",$dates);
	
	$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetaime="%3$s">%4$s</time></a>',
		esc_url(get_day_link($dates_arr[0],$dates_arr[1],$dates_arr[2])),
		esc_attr( get_the_time() ),
		esc_attr( date('Y/m/d H:i:s',strtotime($post->post_date)) ),
		esc_html( call_user_func( 'get_the_date' ) )
	);
	
	$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'jv-hosting' ), get_the_author() ) ),
		get_the_author()
	);

	// Translators: 1 is category, 2 is tag, 3 is the date and 4 is the author's name.
	if ( $tag_list ) {
		$utility_text = __( '
		<span class="category"> <i class="icon-folder2"></i>   %1$s</span> 
		<span class="tag"> <i class="icon-tags2"></i>   %2$s</span> 
		
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		
		', 'jv-hosting' );
	} elseif ( $categories_list ) {
		$utility_text = __( '
		<span class="category"> <i class="icon-folder2"></i>   %1$s</span> 
		
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		', 'jv-hosting' );
	} else {
		$utility_text = __( '
		
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		
		
		', 'jv-hosting' );
	}

	printf(
		$utility_text,
		$categories_list,
		$tag_list,
		$date,
		$author
	);
}
endif;



if ( ! function_exists( 'jv_hosting_entry_meta_no_date_tag' ) ) :

function jv_hosting_entry_meta_no_date_tag() {
	// Translators: used between list items, there is a space after the comma.
	$categories_list = get_the_category_list( __( ', ', 'jv-hosting' ) );

	// Translators: used between list items, there is a space after the comma.
	$tag_list = get_the_tag_list( '', __( ', ', 'jv-hosting' ) );
	
	global $post;

	
	$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'jv-hosting' ), get_the_author() ) ),
		get_the_author()
	);

	if ( $tag_list ) {
		$utility_text = __( '
		<span class="category"> <i class="icon-folder2"></i>   %1$s</span> 
	
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		
		', 'jv-hosting' );
	} elseif ( $categories_list ) {
		$utility_text = __( '
		<span class="category"> <i class="icon-folder2"></i>   %1$s</span> 
		
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		', 'jv-hosting' );
	} else {
		$utility_text = __( '
		
		<span class="by-author"> <i class="icon-user22"></i>  %4$s</span>
		
		
		', 'jv-hosting' );
	}

	printf(
		$utility_text,
		$categories_list,
		$tag_list,
		'',
		//$date,
		$author
	);
}
endif;



if ( ! function_exists( 'jv_hosting_entry_meta_tag' ) ) :
	function jv_hosting_entry_meta_tag() {
		// Translators: used between list items, there is a space after the comma.
		$tag_list = get_the_tag_list( '', __( ', ', 'jv-hosting' ) );
		if ( $tag_list ) {
			$utility_text = __( '%2$s', 'jv-hosting' );
		} 
		printf(
			$tag_list
		);
	}
endif;


/**
 * Extend the default WordPress body classes.
 *
 * Extends the default WordPress body class to denote:
 * 1. Using a full-width layout, when no active widgets in the sidebar
 *    or full-width template.
 * 2. Front Page template: thumbnail in use and number of sidebars for
 *    widget areas.
 * 3. White or empty background color to change the layout and spacing.
 * 4. Custom fonts enabled.
 * 5. Single or multiple authors.
 *
 * @since JV Hosting 1.0
 *
 * @param array $classes Existing class values.
 * @return array Filtered class values.
 */
 if( !function_exists( 'jv_hosting_body_class' ) )
 {
	function jv_hosting_body_class( $classes ) {
		$background_color = get_background_color();
		$background_image = get_background_image();

		if ( ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'page-templates/full-width.php' ) )
			$classes[] = 'full-width';

		if ( is_page_template( 'page-templates/front-page.php' ) ) {
			$classes[] = 'template-front-page';
			if ( has_post_thumbnail() )
				$classes[] = 'has-post-thumbnail';
			if ( is_active_sidebar( 'sidebar-2' ) && is_active_sidebar( 'sidebar-3' ) )
				$classes[] = 'two-sidebars';
		}

		if ( empty( $background_image ) ) {
			if ( empty( $background_color ) )
				$classes[] = 'custom-background-empty';
			elseif ( in_array( $background_color, array( 'fff', 'ffffff' ) ) )
				$classes[] = 'custom-background-white';
		}

		// Enable custom font class only if the font CSS is queued to load.
		if ( wp_style_is( 'Hosting-fonts', 'queue' ) )
			$classes[] = 'custom-font-enabled';

		if ( ! is_multi_author() )
			$classes[] = 'single-author';

		return $classes;
	}
	add_filter( 'body_class', 'jv_hosting_body_class' );
}

/**
 * Adjust content width in certain contexts.
 *
 * Adjusts content_width value for full-width and single image attachment
 * templates, and when there are no active widgets in the sidebar.
 *
 * @since JV Hosting 1.0
 */
 if( !function_exists( 'jv_hosting_content_width' ) )
 {
	function jv_hosting_content_width() {
		if ( is_page_template( 'page-templates/full-width.php' ) || is_attachment() || ! is_active_sidebar( 'sidebar-1' ) ) {
			global $content_width;
			$content_width = 960;
		}
	}
	add_action( 'template_redirect', 'jv_hosting_content_width' );
}
/**
 * Register postMessage support.
 *
 * Add postMessage support for site title and description for the Customizer.
 *
 * @since JV Hosting 1.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
 if( !function_exists( 'jv_hosting_customize_register' ) )
 {
	function jv_hosting_customize_register( $wp_customize ) {
		$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
		$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	}
	add_action( 'customize_register', 'jv_hosting_customize_register' );
}
/**
 * Enqueue Javascript postMessage handlers for the Customizer.
 *
 * Binds JS handlers to make the Customizer preview reload changes asynchronously.
 *
 * @since JV Hosting 1.0
 */
 if( !function_exists( 'jv_hosting_customize_preview_js' ) )
 {
	function jv_hosting_customize_preview_js() {
		wp_enqueue_script( 'hosting-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20130301', true );
	}
	add_action( 'customize_preview_init', 'jv_hosting_customize_preview_js' );
}
//add shortcode id widget
if( !function_exists( 'xyst_widget_shortcode' ) )
{
	function xyst_widget_shortcode( $atts ){
		$abc=call_user_func('extract', shortcode_atts( array(
			'id' => ''
		), $atts ) );
		
		
		$widget = '';
		global $wp_registered_sidebars, $wp_registered_widgets;
		if ( !isset($wp_registered_widgets[$id]) ) return ('Widget "'.$id.'" do not exists!');
		
		ob_start();
		
		$sidebar = array(
			'name' => __( 'Register Shortcode', 'jv-hosting' ),
			'id' => 'sidebar_register_shortcode',
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',

			
		) ;
		
		$params = array_merge(
				array( array_merge( $sidebar, array('widget_id' => $id, 'widget_name' => $wp_registered_widgets[$id]['name']) ) ),
				(array) $wp_registered_widgets[$id]['params']
			);
		
		// Substitute HTML id and class attributes into before_widget
		$classname_ = '';
		foreach ( (array) $wp_registered_widgets[$id]['classname'] as $cn ) {
			if ( is_string($cn) )
				$classname_ .= '_' . $cn;
			elseif ( is_object($cn) )
				$classname_ .= '_' . get_class($cn);
		}
		$classname_ = ltrim($classname_, '_');
		$params[0]['before_widget'] = sprintf($params[0]['before_widget'], $id, $classname_);

		$params = apply_filters( 'dynamic_sidebar_params', $params );

		$callback = $wp_registered_widgets[$id]['callback'];

		do_action( 'dynamic_sidebar', $wp_registered_widgets[$id] );

		if ( is_callable($callback) ) {
			call_user_func_array($callback, $params);
			$did_one = true;
		}
		$widget = ob_get_contents();
		ob_end_clean();    
		
		return $widget;
	}
	JVLibrary::jvShortcode( 'jvwidget', 'xyst_widget_shortcode' );
}	

	
//end add shortcode id widget


// Add Breadcrumb
if( !class_exists( 'the_breadcrumb' ) )
{
	function the_breadcrumb() {
		global $post;
		echo '<ul id="breadcrumbs" class="breadcrumb">';
		if (!is_home()) {
			echo '<li><a href="';
			echo home_url("/");
			echo '">';
			esc_attr_e( 'Home', 'jv-hosting' );
			echo '</a></li>';		
			if (is_category() || is_single()) {
				echo '<li>';

				the_category('-') ; echo '</li>';
				if (is_single()) {
					echo '</li><li>';
					the_title();
					echo '</li>';
				}
			} elseif (is_page()) {
				if($post->post_parent){
					$anc = get_post_ancestors( $post->ID );
					$title = get_the_title();
					foreach ( $anc as $ancestor ) {
						$output = '<li><a href="'.esc_url(get_permalink($ancestor)).'" title="'.esc_attr(get_the_title($ancestor)).'">'.esc_html(get_the_title($ancestor)).'</a></li>';
					}
					echo apply_filters( 'esc_html', $output );
					echo '<li > '.esc_html($title).'</li>';
				} else {
					echo '<li> '.esc_html(get_the_title()).'</li>';
				}
			}
		}
		if (is_tag()) { echo"<li>"; single_tag_title(); echo"</li>"; }
		
		if (is_day()) {	$day_s='F jS, Y';echo"<li> "; esc_attr_e( 'Archive for', 'jv-hosting' ); echo "<span>"; the_time($day_s); echo'</span></li>';}
		if (is_month()) { $month_s='F, Y'; echo"<li>"; esc_attr_e( 'Archive for', 'jv-hosting' );echo "<span>"; the_time($month_s); echo'</span></li>';}
		if (is_year()) { $year_s='Y'; echo"<li>"; esc_attr_e( 'Archive for', 'jv-hosting' );echo "<span>"; the_time($year_s); echo'</span></li>';}
		if (is_author()) {echo"<li>"; esc_attr_e( 'Author Archive', 'jv-hosting' ); echo'</li>';}
		if (isset($_GET['paged']) && !empty($_GET['paged'])) {echo "<li>"; esc_attr_e( 'Blog Archives', 'jv-hosting' ); echo'</li>';}
		if (is_search()) {echo"<li>";esc_attr_e( 'Search Results', 'jv-hosting' );  echo'</li>';}
		echo '</ul>';
	}
}
// End Breadcrumb : the_breadcrumb(); 
if( !function_exists( 'acreate_function' ) )
{
	add_filter( 'loop_shop_per_page', "acreate_function", 20 );

	function acreate_function(){
		return 15;
	}
}

if( !function_exists( 'jv_hosting_post_nav_background' ) )
{
	function jv_hosting_post_nav_background() {
		if ( ! is_single() ) {
			return;
		}
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );
		$css      = '';

		if ( is_attachment() && 'attachment' == $previous->post_type ) {
			return;
		}

		if ( $previous &&  has_post_thumbnail( $previous->ID ) ) {
			$prevthumb = wp_get_attachment_image_src( get_post_thumbnail_id( $previous->ID ), 'post-thumbnail' );
			$css .= '
				.post-navigation .nav-previous { background-image: url(' . esc_url( $prevthumb[0] ) . '); }
				.post-navigation .nav-previous .post-title, .post-navigation .nav-previous a:hover .post-title, .post-navigation .nav-previous .meta-nav { color: #fff; }
				.post-navigation .nav-previous a:before { background-color: rgba(0, 0, 0, 0.4); }
			';
		}

		if ( $next && has_post_thumbnail( $next->ID ) ) {
			$nextthumb = wp_get_attachment_image_src( get_post_thumbnail_id( $next->ID ), 'post-thumbnail' );
			$css .= '
				.post-navigation .nav-next { background-image: url(' . esc_url( $nextthumb[0] ) . '); }
				.post-navigation .nav-next .post-title, .post-navigation .nav-next a:hover .post-title, .post-navigation .nav-next .meta-nav { color: #fff; }
				.post-navigation .nav-next a:before { background-color: rgba(0, 0, 0, 0.4); }
			';
		}

		wp_add_inline_style( 'Hosting-style', $css );
	}
	add_action( 'wp_enqueue_scripts', 'jv_hosting_post_nav_background' );
}

/* Single product - part tab product */
if( !function_exists( 'jvwoo_custom_tab' ) )
{
	function jvwoo_custom_tab ( $pid ){
		
		$text = '';
		
		if( ( $data = get_post_meta( $pid, 'frs_woo_product_tabs', true ) ) && is_array ( $data ) ) {
			
			foreach( $data as $tab ) {
			
				$content = apply_filters( 'the_content', $tab['content'] );
			
				$text .= apply_filters( 'woocommerce_custom_product_tabs_lite_heading', '<h4>' . $tab['title'] . '</h4>', $tab );
				$text .= apply_filters( 'woocommerce_custom_product_tabs_lite_content', $content, $tab );
			}
		}
		
		return $text; 
	}
	add_filter( 'jvwoo-custom-tab', 'jvwoo_custom_tab', 10, 1 );
}

if( !function_exists( 'woocommerce_product_tabs' ) )
{
	function woocommerce_product_tabs( $tabs ){
		
		if( !count( $tabs ) ) { return false; }
		
		foreach( $tabs as $key => $tab ) {
				
			if( !is_array( $tab['callback'] ) ) { continue; }
			
			foreach( $tab['callback'] as $fn ) {
				
				if( get_class( $fn ) === 'WooCommerceCustomProductTabsLite' || $fn === 'custom_product_tabs_panel_content' ) {
				
					unset( $tabs[ $key ] );
					break;
				}
			}
		}
		
		return $tabs;
	}
	add_filter( 'woocommerce_product_tabs', 'woocommerce_product_tabs', 99999);
}
/* End Single product - part tab product */

/* add filter render field search */
if( !function_exists( 'render_form_search' ) )
{
	function render_form_search(){
		return function_exists( 'is_woocommerce' ) && is_woocommerce() ? do_shortcode("[woo_search]") : get_search_form();
	}
	add_filter( 'render_form_search', 'render_form_search', 10);
}

if( !function_exists( 'megamenu_javascript_localisation' ) ) {
	function megamenu_javascript_localisation( $params ) {
		
		if( isset( $params[ 'timeout' ] ) ) {
			$params[ 'timeout' ] = 100;
		}
		
		return $params;
	}
}
add_filter( 'megamenu_javascript_localisation', 'megamenu_javascript_localisation', 9999, 1 );

/* Categories Posts*/
if( !function_exists( 'add_span_cat_count' ) )
{
	add_filter('wp_list_categories', 'add_span_cat_count');
	function add_span_cat_count($links) {
		$links = str_replace('</a> (', '</a> <span class="count">', $links);
		$links = str_replace(')', '</span>', $links);
		return $links;
	}
}

/* Related Posts*/
if( !function_exists( 'MyRelatedPostsShortcode' ) )
{
	function MyRelatedPostsShortcode($atts){
	   call_user_func( 'extract', shortcode_atts(array(
		'number' => 5,
		'tag' => '',
		'id' => get_the_ID(),
		'author' => ''
		   ), $atts));
		   
		   $q = array( 'orderby' => 'date', 'order' => 'DESC' , 'showposts' => $number , 'post__not_in' => array( $id ), 'tag__not_in' => array(00001, 00002, 00003) );
		   
		   if( $tag ) { $q[ 'tag__in' ] = explode(',', $tag ); }
		   if( $author ) { $q[ 'author' ] = $author; }
		   
		   $return_string = '<ul class="list-checked list-angle-right">';
		   
		   $the_query = new WP_Query( $q );
		   
			if ( $the_query->have_posts() ) { while ( $the_query->have_posts() ) 
			{
				$the_query->the_post();
				$return_string .= '<li><a target="_blank" href="'.get_permalink().'" title="'.get_the_title().'">'.get_the_title().'</a></li>';
			}
				} else {
			}
			wp_reset_postdata();
	   $return_string .= '</ul>';
	   return $return_string;
	}
	call_user_func( 'add_' . 'shortcode', 'my-related-posts', 'MyRelatedPostsShortcode' );
}


/*echo allione date: TRUE for full month else short*/
if( !function_exists( 'jv_echo_date_hosting' ) )
{
	function jv_echo_date_hosting($fullmonth=false){
		?>
		<div class="date test">
			<h2 class="date border circle gray"><?php echo apply_filters( 'esc_html', call_user_func( 'get_the_date', 'j') ); ?></h2>
			<h4 class="month">
				<?php echo ($fullmonth)? apply_filters( 'esc_html', call_user_func( 'get_the_date', 'F') ): apply_filters( 'esc_html', call_user_func( 'get_the_date', 'M') ); ?>
			</h4>
			<h5 class="year"><?php echo apply_filters( 'esc_html', call_user_func( 'get_the_date', 'Y' ) ); ?></h5>
		</div>
		
		<?php
	}
}

if( !function_exists( 'jv_get_metaicon' ) )
{
	function jv_get_metaicon($classblog="default"){
		$metaicon ="";
		switch ($classblog) {
			case 'blog-audio':
				$metaicon ="icon-soundcloud";
				break;
			case 'blog-video':
				$metaicon ="icon-film8";
				break;
			case 'blog-gallery':
			case 'blog-slideshow':
				$metaicon = "icon-pictures7";
				break;
			case 'blog-thumbnail':
				$metaicon = "icon-picture3";
				break;
			default:{
				switch ( get_post_format()) {
					case 'gallery':
						$metaicon = "icon-pictures7";
						break;
					case 'image':
						$metaicon = "icon-picture3";
						break;
					case 'video':
						$metaicon ="icon-film8";
						break;
					case 'audio':
						$metaicon ="icon-soundcloud";
						break;
					case 'quote':
						$metaicon = "icon-quotes-left";
						break;
					case 'link':
						$metaicon = "icon-link3";
						break;
					case 'chat':
						$metaicon = "icon-chat-2";
						break;
					case 'status':
						$metaicon = "icon-comments2";
						break;
					case 'aside':
						$metaicon = "icon-layout10";
						break;
					default:
						$metaicon = "icon-text";
						break;
				}

				break;
			}
				
		}
		return $metaicon;
	}
}